@@ -586,10 +586,10 @@ static const yytype_uint8 yytranslate[] =
   /* YYRLINE[YYN] -- Source line where rule number YYN was defined.  */
 static const yytype_uint16 yyrline[] =
 {
-       0,   199,   199,   200,   201,   204,   205,   208,   209,   210,
-     211,   213,   216,   218,   220,   224,   225,   228,   234,   235,
-     236,   238,   240,   242,   243,   244,   245,   246,   247,   248,
-     251,   254,   255,   256,   257,   258
+       0,   199,   199,   201,   202,   205,   206,   209,   210,   211,
+     212,   214,   217,   219,   221,   225,   226,   229,   235,   236,
+     237,   239,   241,   243,   244,   245,   246,   247,   248,   249,
+     252,   255,   256,   257,   258,   259
 };
 #endif
 
@@ -1457,221 +1457,222 @@ yyreduce:
     {
         case 2:
 #line 199 "parse.y" /* yacc.c:1646  */
-    { comm->result = makenumunit(1,&err); CHECK(0); YYACCEPT; }
-#line 1462 "parse.tab.c" /* yacc.c:1646  */
+    { comm->result = makenumunit(1,&err); CHECK(0);
+                       comm->errorcode = 0; YYACCEPT; }
+#line 1463 "parse.tab.c" /* yacc.c:1646  */
     break;
 
   case 3:
-#line 200 "parse.y" /* yacc.c:1646  */
-    { comm->result = (yyvsp[-1].unit); YYACCEPT; }
-#line 1468 "parse.tab.c" /* yacc.c:1646  */
+#line 201 "parse.y" /* yacc.c:1646  */
+    { comm->result = (yyvsp[-1].unit); comm->errorcode = 0; YYACCEPT; }
+#line 1469 "parse.tab.c" /* yacc.c:1646  */
     break;
 
   case 4:
-#line 201 "parse.y" /* yacc.c:1646  */
+#line 202 "parse.y" /* yacc.c:1646  */
     { YYABORT; }
-#line 1474 "parse.tab.c" /* yacc.c:1646  */
+#line 1475 "parse.tab.c" /* yacc.c:1646  */
     break;
 
   case 5:
-#line 204 "parse.y" /* yacc.c:1646  */
+#line 205 "parse.y" /* yacc.c:1646  */
     { (yyval.unit) = (yyvsp[0].unit);}
-#line 1480 "parse.tab.c" /* yacc.c:1646  */
+#line 1481 "parse.tab.c" /* yacc.c:1646  */
     break;
 
   case 6:
-#line 205 "parse.y" /* yacc.c:1646  */
+#line 206 "parse.y" /* yacc.c:1646  */
     { invertunit((yyvsp[0].unit)); (yyval.unit)=(yyvsp[0].unit);}
-#line 1486 "parse.tab.c" /* yacc.c:1646  */
+#line 1487 "parse.tab.c" /* yacc.c:1646  */
     break;
 
   case 7:
-#line 208 "parse.y" /* yacc.c:1646  */
+#line 209 "parse.y" /* yacc.c:1646  */
     { (yyval.unit) = (yyvsp[0].unit); }
-#line 1492 "parse.tab.c" /* yacc.c:1646  */
+#line 1493 "parse.tab.c" /* yacc.c:1646  */
     break;
 
   case 8:
-#line 209 "parse.y" /* yacc.c:1646  */
+#line 210 "parse.y" /* yacc.c:1646  */
     { (yyval.unit) = (yyvsp[0].unit); (yyval.unit)->factor *= -1; }
-#line 1498 "parse.tab.c" /* yacc.c:1646  */
+#line 1499 "parse.tab.c" /* yacc.c:1646  */
     break;
 
   case 9:
-#line 210 "parse.y" /* yacc.c:1646  */
+#line 211 "parse.y" /* yacc.c:1646  */
     { (yyval.unit) = (yyvsp[0].unit); (yyval.unit)->factor *= -1; }
-#line 1504 "parse.tab.c" /* yacc.c:1646  */
+#line 1505 "parse.tab.c" /* yacc.c:1646  */
     break;
 
   case 10:
-#line 211 "parse.y" /* yacc.c:1646  */
+#line 212 "parse.y" /* yacc.c:1646  */
     { err = addunit((yyvsp[-2].unit),(yyvsp[0].unit)); destroyunit((yyvsp[0].unit));
                                       CHECK((yyvsp[-2].unit));(yyval.unit)=(yyvsp[-2].unit);}
-#line 1511 "parse.tab.c" /* yacc.c:1646  */
+#line 1512 "parse.tab.c" /* yacc.c:1646  */
     break;
 
   case 11:
-#line 213 "parse.y" /* yacc.c:1646  */
+#line 214 "parse.y" /* yacc.c:1646  */
     { (yyvsp[0].unit)->factor *= -1;
                                       err = addunit((yyvsp[-2].unit),(yyvsp[0].unit)); destroyunit((yyvsp[0].unit));
                                       CHECK((yyvsp[-2].unit));(yyval.unit)=(yyvsp[-2].unit);}
-#line 1519 "parse.tab.c" /* yacc.c:1646  */
+#line 1520 "parse.tab.c" /* yacc.c:1646  */
     break;
 
   case 12:
-#line 216 "parse.y" /* yacc.c:1646  */
+#line 217 "parse.y" /* yacc.c:1646  */
     { err = divunit((yyvsp[-2].unit), (yyvsp[0].unit)); destroyunit((yyvsp[0].unit));
                                       CHECK((yyvsp[-2].unit));(yyval.unit)=(yyvsp[-2].unit);}
-#line 1526 "parse.tab.c" /* yacc.c:1646  */
+#line 1527 "parse.tab.c" /* yacc.c:1646  */
     break;
 
   case 13:
-#line 218 "parse.y" /* yacc.c:1646  */
+#line 219 "parse.y" /* yacc.c:1646  */
     { err = multunit((yyvsp[-2].unit),(yyvsp[0].unit)); destroyunit((yyvsp[0].unit));
                                       CHECK((yyvsp[-2].unit));(yyval.unit)=(yyvsp[-2].unit);}
-#line 1533 "parse.tab.c" /* yacc.c:1646  */
+#line 1534 "parse.tab.c" /* yacc.c:1646  */
     break;
 
   case 14:
-#line 220 "parse.y" /* yacc.c:1646  */
+#line 221 "parse.y" /* yacc.c:1646  */
     { err = multunit((yyvsp[-2].unit),(yyvsp[0].unit)); destroyunit((yyvsp[0].unit));
                                       CHECK((yyvsp[-2].unit));(yyval.unit)=(yyvsp[-2].unit);}
-#line 1540 "parse.tab.c" /* yacc.c:1646  */
+#line 1541 "parse.tab.c" /* yacc.c:1646  */
     break;
 
   case 15:
-#line 224 "parse.y" /* yacc.c:1646  */
+#line 225 "parse.y" /* yacc.c:1646  */
     { (yyval.number) = (yyvsp[0].number);         }
-#line 1546 "parse.tab.c" /* yacc.c:1646  */
+#line 1547 "parse.tab.c" /* yacc.c:1646  */
     break;
 
   case 16:
-#line 225 "parse.y" /* yacc.c:1646  */
+#line 226 "parse.y" /* yacc.c:1646  */
     { (yyval.number) = (yyvsp[-2].number) / (yyvsp[0].number);    }
-#line 1552 "parse.tab.c" /* yacc.c:1646  */
+#line 1553 "parse.tab.c" /* yacc.c:1646  */
     break;
 
   case 17:
-#line 228 "parse.y" /* yacc.c:1646  */
+#line 229 "parse.y" /* yacc.c:1646  */
     { (yyval.unit) = (yyvsp[-1].unit);  }
-#line 1558 "parse.tab.c" /* yacc.c:1646  */
+#line 1559 "parse.tab.c" /* yacc.c:1646  */
     break;
 
   case 18:
-#line 234 "parse.y" /* yacc.c:1646  */
+#line 235 "parse.y" /* yacc.c:1646  */
     { (yyval.unit) = makenumunit((yyvsp[0].number),&err); CHECK(0);}
-#line 1564 "parse.tab.c" /* yacc.c:1646  */
+#line 1565 "parse.tab.c" /* yacc.c:1646  */
     break;
 
   case 19:
-#line 235 "parse.y" /* yacc.c:1646  */
+#line 236 "parse.y" /* yacc.c:1646  */
     { (yyval.unit) = (yyvsp[0].unit); }
-#line 1570 "parse.tab.c" /* yacc.c:1646  */
+#line 1571 "parse.tab.c" /* yacc.c:1646  */
     break;
 
   case 20:
-#line 236 "parse.y" /* yacc.c:1646  */
+#line 237 "parse.y" /* yacc.c:1646  */
     { err = unitpower((yyvsp[-2].unit),(yyvsp[0].unit));destroyunit((yyvsp[0].unit));
                                      CHECK((yyvsp[-2].unit));(yyval.unit)=(yyvsp[-2].unit);}
-#line 1577 "parse.tab.c" /* yacc.c:1646  */
+#line 1578 "parse.tab.c" /* yacc.c:1646  */
     break;
 
   case 21:
-#line 238 "parse.y" /* yacc.c:1646  */
+#line 239 "parse.y" /* yacc.c:1646  */
     { err = multunit((yyvsp[-2].unit),(yyvsp[0].unit)); destroyunit((yyvsp[0].unit));
                                      CHECK((yyvsp[-2].unit));(yyval.unit)=(yyvsp[-2].unit);}
-#line 1584 "parse.tab.c" /* yacc.c:1646  */
+#line 1585 "parse.tab.c" /* yacc.c:1646  */
     break;
 
   case 22:
-#line 240 "parse.y" /* yacc.c:1646  */
+#line 241 "parse.y" /* yacc.c:1646  */
     { err = multunit((yyvsp[-1].unit),(yyvsp[0].unit)); destroyunit((yyvsp[0].unit));
                                      CHECK((yyvsp[-1].unit));(yyval.unit)=(yyvsp[-1].unit);}
-#line 1591 "parse.tab.c" /* yacc.c:1646  */
+#line 1592 "parse.tab.c" /* yacc.c:1646  */
     break;
 
   case 23:
-#line 242 "parse.y" /* yacc.c:1646  */
+#line 243 "parse.y" /* yacc.c:1646  */
     { (yyval.unit)=(yyvsp[0].unit); }
-#line 1597 "parse.tab.c" /* yacc.c:1646  */
+#line 1598 "parse.tab.c" /* yacc.c:1646  */
     break;
 
   case 24:
-#line 243 "parse.y" /* yacc.c:1646  */
+#line 244 "parse.y" /* yacc.c:1646  */
     { err = rootunit((yyvsp[0].unit),2); CHECK((yyvsp[0].unit)); (yyval.unit)=(yyvsp[0].unit);}
-#line 1603 "parse.tab.c" /* yacc.c:1646  */
+#line 1604 "parse.tab.c" /* yacc.c:1646  */
     break;
 
   case 25:
-#line 244 "parse.y" /* yacc.c:1646  */
+#line 245 "parse.y" /* yacc.c:1646  */
     { err = rootunit((yyvsp[0].unit),3); CHECK((yyvsp[0].unit)); (yyval.unit)=(yyvsp[0].unit);}
-#line 1609 "parse.tab.c" /* yacc.c:1646  */
+#line 1610 "parse.tab.c" /* yacc.c:1646  */
     break;
 
   case 26:
-#line 245 "parse.y" /* yacc.c:1646  */
+#line 246 "parse.y" /* yacc.c:1646  */
     { err = funcunit((yyvsp[0].unit),(yyvsp[-1].realfunc));CHECK((yyvsp[0].unit)); (yyval.unit)=(yyvsp[0].unit);}
-#line 1615 "parse.tab.c" /* yacc.c:1646  */
+#line 1616 "parse.tab.c" /* yacc.c:1646  */
     break;
 
   case 27:
-#line 246 "parse.y" /* yacc.c:1646  */
-    { err = evalfunc((yyvsp[0].unit),(yyvsp[-1].unitfunc),0,0); CHECK((yyvsp[0].unit)); (yyval.unit)=(yyvsp[0].unit);}
-#line 1621 "parse.tab.c" /* yacc.c:1646  */
+#line 247 "parse.y" /* yacc.c:1646  */
+    { err = evalfunc((yyvsp[0].unit),(yyvsp[-1].unitfunc),0,0); CHECK((yyvsp[0].unit));(yyval.unit)=(yyvsp[0].unit);}
+#line 1622 "parse.tab.c" /* yacc.c:1646  */
     break;
 
   case 28:
-#line 247 "parse.y" /* yacc.c:1646  */
-    { err = evalfunc((yyvsp[0].unit),(yyvsp[-1].unitfunc),1,0); CHECK((yyvsp[0].unit)); (yyval.unit)=(yyvsp[0].unit);}
-#line 1627 "parse.tab.c" /* yacc.c:1646  */
+#line 248 "parse.y" /* yacc.c:1646  */
+    { err = evalfunc((yyvsp[0].unit),(yyvsp[-1].unitfunc),1,0); CHECK((yyvsp[0].unit));(yyval.unit)=(yyvsp[0].unit);}
+#line 1628 "parse.tab.c" /* yacc.c:1646  */
     break;
 
   case 29:
-#line 249 "parse.y" /* yacc.c:1646  */
+#line 250 "parse.y" /* yacc.c:1646  */
     { (yyvsp[0].unit)->factor *= -1; err = unitpower((yyvsp[-3].unit),(yyvsp[0].unit));
                                      destroyunit((yyvsp[0].unit));CHECK((yyvsp[-3].unit));(yyval.unit)=(yyvsp[-3].unit);}
-#line 1634 "parse.tab.c" /* yacc.c:1646  */
+#line 1635 "parse.tab.c" /* yacc.c:1646  */
     break;
 
   case 30:
-#line 252 "parse.y" /* yacc.c:1646  */
+#line 253 "parse.y" /* yacc.c:1646  */
     { (yyvsp[0].unit)->factor *= -1; err = unitpower((yyvsp[-3].unit),(yyvsp[0].unit));
                                      destroyunit((yyvsp[0].unit));CHECK((yyvsp[-3].unit));(yyval.unit)=(yyvsp[-3].unit);}
-#line 1641 "parse.tab.c" /* yacc.c:1646  */
+#line 1642 "parse.tab.c" /* yacc.c:1646  */
     break;
 
   case 31:
-#line 254 "parse.y" /* yacc.c:1646  */
+#line 255 "parse.y" /* yacc.c:1646  */
     { err = E_BADNUM;   CHECK(0); }
-#line 1647 "parse.tab.c" /* yacc.c:1646  */
+#line 1648 "parse.tab.c" /* yacc.c:1646  */
     break;
 
   case 32:
-#line 255 "parse.y" /* yacc.c:1646  */
+#line 256 "parse.y" /* yacc.c:1646  */
     { err = E_PARSEMEM; CHECK(0); }
-#line 1653 "parse.tab.c" /* yacc.c:1646  */
+#line 1654 "parse.tab.c" /* yacc.c:1646  */
     break;
 
   case 33:
-#line 256 "parse.y" /* yacc.c:1646  */
+#line 257 "parse.y" /* yacc.c:1646  */
     { err = E_UNITEND;  CHECK(0); }
-#line 1659 "parse.tab.c" /* yacc.c:1646  */
+#line 1660 "parse.tab.c" /* yacc.c:1646  */
     break;
 
   case 34:
-#line 257 "parse.y" /* yacc.c:1646  */
+#line 258 "parse.y" /* yacc.c:1646  */
     { err = E_LASTUNSET;CHECK(0); }
-#line 1665 "parse.tab.c" /* yacc.c:1646  */
+#line 1666 "parse.tab.c" /* yacc.c:1646  */
     break;
 
   case 35:
-#line 258 "parse.y" /* yacc.c:1646  */
+#line 259 "parse.y" /* yacc.c:1646  */
     { err = E_NOTAFUNC; CHECK((yyvsp[0].unit));}
-#line 1671 "parse.tab.c" /* yacc.c:1646  */
+#line 1672 "parse.tab.c" /* yacc.c:1646  */
     break;
 
 
-#line 1675 "parse.tab.c" /* yacc.c:1646  */
+#line 1676 "parse.tab.c" /* yacc.c:1646  */
       default: break;
     }
   /* User semantic actions sometimes alter yychar, and that requires
@@ -1899,7 +1900,7 @@ yyreturn:
 #endif
   return yyresult;
 }
-#line 261 "parse.y" /* yacc.c:1906  */
+#line 262 "parse.y" /* yacc.c:1906  */
 
 
 struct function 
